@@ -46,7 +46,10 @@ fn main() -> Result<(), Box<dyn Error>> {
 
     // Create app and run it
     let mut app = App::new(cards, opts);
-    app.read_scores()?;
+    if !app.opts.reset {
+        app.read_scores()?;
+        app.order_playables();
+    }
 
     // setup terminal
     enable_raw_mode()?;
@@ -90,11 +93,11 @@ fn run_app<B: Backend>(
                     return Ok(false);
                 }
                 KeyCode::Char('j') => {
-                    app.change_card_score(-1);
+                    app.change_current_card_score(-1);
                     app.next_card();
                 }
                 KeyCode::Char('k') => {
-                    app.change_card_score(1);
+                    app.change_current_card_score(1);
                     app.next_card();
                 }
                 _ => {}
@@ -102,6 +105,7 @@ fn run_app<B: Backend>(
         }
     }
 
+    app.write_scores()?;
     Ok(true)
 }
 
